pilas.municion.Municion

Package pilas :: Module municion :: Class Municion |
[hide private]
[frames] | no frames]

# Class Municion

source code

    object --+
             |
            Municion

Known Subclasses:
  - BalaDoble
  - , BalasDoblesDesviadas
  - , MisilDoble

Clase base para representar un conjunto de proyectiles que pueden ser disparados mediante la habilidad de Disparar.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
disparar(self, x, y, rotacion, angulo_de_movimiento, offset_disparo_x, offset_disparo_y) Este método debe ser sobreescrito. | source code
agregar_proyectil(self, proyectil) Agrega un proyectil a la lista de proyectiles de la munición. | source code
get_proyectiles(self) Obtiene los proyectiles que acaba de disparar la munición. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| proyectiles Obtiene los proyectiles de la munición.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### agregar_proyectil(self, proyectil) | source code
Agrega un proyectil a la lista de proyectiles de la munición. :param proyectil: Actor que se añadirá a la lista de proyectiles.

Property Details | [hide private]

### proyectiles Obtiene los proyectiles de la munición. Get Method: get_proyectiles(self) - Obtiene los proyectiles que acaba de disparar la munición.